
  

# Neural-network policy trainer for agent-based modeling

  

This package ...

- S

  
## Getting started

### Quick start

`pip install --upgrade ..`

```py



```

```py



```

### More on it



## Install

Using pip manager:

-  `pip install --upgrade ...`

Or, download the package and in the root folder, command:

-  `python3 setup.py install`

## Authors

- Jalil Nourisa

## Useful links

 [PyTorch](https://github.com/pytorch/pytorch).

### Acknowledgments

No one yet. Give some feedback so your name would appear here :-)
